summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/widgetpropertyset.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /kexi/formeditor/widgetpropertyset.h
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kexi/formeditor/widgetpropertyset.h')
-rw-r--r--kexi/formeditor/widgetpropertyset.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kexi/formeditor/widgetpropertyset.h b/kexi/formeditor/widgetpropertyset.h
index afb303d1..f1f96a99 100644
--- a/kexi/formeditor/widgetpropertyset.h
+++ b/kexi/formeditor/widgetpropertyset.h
@@ -157,15 +157,15 @@ class KFORMEDITOR_EXPORT WidgetPropertySet : public TQObject
// Following functions are used to create special types of properties, different
// from TQ_PROPERTY
/*! Creates the properties related to tqalignment (ie hAlign, vAlign and WordBreak) for
the TQWidget \a widget. \a subwidget is the same as \a widget if the widget itself handles
the property and it's a child widget if the child handles the property.
For example, the second case is true for KexiDBAutoField.
- \a meta is the TQMetaProperty for "tqalignment" property" of subwidget. */
+ \a meta is the TQMetaProperty for "alignment" property" of subwidget. */
void createAlignProperty(const TQMetaProperty *meta, TQWidget *widget, TQWidget *subwidget);
- /*! Saves the properties related to tqalignment (ie hAlign, vAlign and WordBreak)
- and modifies the "tqalignment" property of the widget.*/
+ /*! Saves the properties related to alignment (ie hAlign, vAlign and WordBreak)
+ and modifies the "alignment" property of the widget.*/
void saveAlignProperty(const TQString &property);
/*! Creates the "tqlayout" property, for the Container representing \a item. */
@@ -157,15 +157,15 @@ class KFORMEDITOR_EXPORT WidgetPropertySet : public TQObject
// Following functions are used to create special types of properties, different
// from TQ_PROPERTY
- /*! Creates the properties related to tqalignment (ie hAlign, vAlign and WordBreak) for
+ /*! Creates the properties related to alignment (ie hAlign, vAlign and WordBreak) for
the TQWidget \a widget. \a subwidget is the same as \a widget if the widget itself handles
the property and it's a child widget if the child handles the property.